pub fn log_benchmark_header()Expand description
Logs the header/column names of the benchmarks table to the browser
console (with console.log).
pub fn log_benchmark_header()Logs the header/column names of the benchmarks table to the browser
console (with console.log).